/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */


#include "domstubs.idl"
interface nsIContentFrameMessageManager;
interface nsIWebBrowserChrome3;

native CommandsArray(nsTArray<nsCString>);
[ref] native CommandsArrayRef(nsTArray<nsCString>);

[scriptable, uuid(7227bac4-b6fe-4090-aeb4-bc288b790925)]
interface nsITabChild : nsISupports
{
  readonly attribute nsIContentFrameMessageManager messageManager;

  attribute nsIWebBrowserChrome3 webBrowserChrome;

  [notxpcom] void sendRequestFocus(in boolean canFocus);

  [noscript, notxpcom] void enableDisableCommands(in AString action,
                                                  in CommandsArrayRef enabledCommands,
                                                  in CommandsArrayRef disabledCommands);
};

